@@ -59,8 +59,7 @@ variableTypes <- function(table) {
 
 #' @noRd
 assertClassification <- function(x) {
-  switch (
-    x,
+  switch(x,
     "chr" = "categorical",
     "fct" = "categorical",
     "ord" = "categorical",
@@ -75,42 +74,6 @@ assertClassification <- function(x) {
   )
 }
 
-#' Show the available functions for the 4 classifications of data that are
-#' supported (numeric, date, binary and categorical)
-#'
-#' @param variableType A choice between: "numeric", "date", "binary"
-#' or "categorical".
-#'
-#' @return A tibble with the available functions for a certain variable
-#' classification (or all if NULL).
-#'
-#' @examples
-#' \donttest{
-#' library(PatientProfiles)
-#'
-#' availableFunctions()
-#' availableFunctions("numeric")
-#' availableFunctions("integer")
-#' availableFunctions("date")
-#' availableFunctions("categorical")
-#' availableFunctions("logical")
-#' }
-#'
-#' @export
-#'
-availableFunctions <- function(variableType = NULL) {
-  lifecycle::deprecate_warn("0.7.0", what = "availableFunctions()", with = "availableEstimates()")
-  if (is.null(variableType)) {
-    return(formatsOld)
-  } else {
-    checkVariableType(variableType)
-    x <- formatsOld %>%
-      dplyr::filter(.data$variable_type == .env$variableType) %>%
-      dplyr::select(-"variable_type")
-    return(x)
-  }
-}
-
 #' Show the available estimates that can be used for the different variable_type
 #' supported.
 #'
@@ -131,7 +94,7 @@ availableFunctions <- function(variableType = NULL) {
 #'
 #' @export
 #'
-availableEstimates <- function(variableType = NULL, fullQuantiles = FALSE){
+availableEstimates <- function(variableType = NULL, fullQuantiles = FALSE) {
   opts <- unique(formats$variable_type)
   if (is.null(variableType)) {
     variableType <- opts
@@ -509,6 +472,3 @@ getFunctions <- function(f) {
   )
   return(estimatesFunc[f])
 }
-
-
-
